@@ -1,69 +1,32 @@
 """Main module."""
 
+import pwd
 import os
-from datetime import datetime, date, timezone
-import json
-
-import shlex
-
-import functools
-from pprint import pprint
-from slugify import slugify
-import batchspawner
-from jupyterhub.spawner import LocalProcessSpawner
-from jinja2 import Environment, BaseLoader
-from jupyterhub.spawner import Spawner
-from traitlets import Integer, Unicode, Float, Dict, default
-from traitlets import (
-    Bool,
-    Dict,
-    Integer,
-    List,
-    Unicode,
-    Union,
-    default,
-    observe,
-    validate,
-)
-
-from typing import List, Union
-from datasize import DataSize
-import humanize
-from dataclasses import dataclass
-from pathlib import Path
-import boto3
-import os
-# from aws_pcluster_helpers import (SinfoRow, SInfoTable)
-from aws_pcluster_helpers.models.sinfo import (SInfoTable, SinfoRow)
 import time
+from datetime import datetime
+from typing import List
+
+import batchspawner
+from aws_pcluster_helpers.models.sinfo import (SInfoTable, SinfoRow)
+from jinja2 import Environment, BaseLoader
+from slugify import slugify
 
 pcluster_spawner_template_paths = os.path.join(os.path.dirname(__file__), 'templates')
 
+from typing import Any
 import requests
-import asyncio
 from async_generator import async_generator, yield_
-import pwd
 import os
-import re
-
-import xml.etree.ElementTree as ET
-
-from enum import Enum
-
-from jinja2 import Template
 
 from tornado import gen
 
-from jupyterhub.spawner import Spawner
-from traitlets import Integer, Unicode, Float, Dict, default
-
-from jupyterhub.spawner import set_user_setuid
+from traitlets import Unicode, Dict
 
 
 class PClusterSlurmSpawner(batchspawner.SlurmSpawner):
     # This is tied to the dict returned by the submission_data function
     batch_script = Unicode("""#!/bin/bash
-#SBATCH --output={{homedir}}/jupyterhub_%j.log
+#SBATCH --output={{homedir}}/logs/jupyterhub_%j.log
 #SBATCH --job-name=jupyterhub
 #SBATCH --chdir={{homedir}}
 #SBATCH --export={{keepvars}}
@@ -180,7 +143,7 @@ echo "jupyterhub-singleuser ended gracefully"
         return profile_form_template.render(profile_list=self._profile_list)
 
     @property
-    def profiles_list(self) -> List[Dict]:
+    def profiles_list(self) -> List[Dict[str, Any]]:
         """
         List of profiles to offer for selection by the user.
         Signature is: `List(Dict())`, where each item is a dictionary that has two keys:
@@ -302,13 +265,22 @@ echo "jupyterhub-singleuser ended gracefully"
         5  mem-dy-m5a4xlarge  mem_dy__m5a_4xlarge   mem  m5a4xlarge       m5a.4xlarge   64    8  None   []    {}
         7  mem-dy-c6a8xlarge  mem_dy__c6a_8xlarge   mem  c6a8xlarge       c6a.8xlarge   64   16  None   []    {}
         """
-        groups = self.sinfo.dataframe.groupby('queue').groups
-        profiles = []
-        for key in groups.keys():
-            group = self.sinfo.dataframe.groupby('queue').get_group(key)
-            profile = {
-                'display_name': f'Queue: {key}',
-                'slug': key,
+        profiles = [
+            {
+                'display_name': f'CPU',
+                'slug': 'cpu',
+                'ami_name': 'Deep Learning',
+                'profile_options': {
+                    'instance_types': {
+                        'display_name': 'Instance Types',
+                        'choices': {
+                        }
+                    },
+                },
+            },
+            {
+                'display_name': f'GPU',
+                'slug': 'gpu',
                 'ami_name': 'Deep Learning',
                 'profile_options': {
                     'instance_types': {
@@ -318,18 +290,27 @@ echo "jupyterhub-singleuser ended gracefully"
                     },
                 },
             }
-            for group_record in group.to_dict('records'):
-                sinfo_name = group_record['sinfo_name']
-                instance_type = group_record['ec2_instance_type']
+        ]
+        gpu_found = False
+        for group_record in self.sinfo.dataframe.to_dict('records'):
+            sinfo_name = group_record['sinfo_name']
+            instance_type = group_record['ec2_instance_type']
 
-                mem = group_record['mem']
-                cpu = group_record['vcpu']
-                profile['profile_options']['instance_types']['choices'][sinfo_name] = dict(
+            mem = group_record['mem']
+            cpu = group_record['vcpu']
+            if len(group_record['gpus']):
+                profiles[1]['profile_options']['instance_types']['choices'][sinfo_name] = dict(
                     display_name=f'{instance_type} - {cpu} CPU, {mem} GB',
                     pclusterslurmspawner_override=group_record,
                 )
-
-            profiles.append(profile)
+            else:
+                gpu_found = True
+                profiles[0]['profile_options']['instance_types']['choices'][sinfo_name] = dict(
+                    display_name=f'{instance_type} - {cpu} CPU, {mem} GB',
+                    pclusterslurmspawner_override=group_record,
+                )
+        if not gpu_found:
+            profiles.pop()
         return profiles
 
     @property
@@ -360,7 +341,7 @@ echo "jupyterhub-singleuser ended gracefully"
             defaults = {
                 'req_nprocs': str(first_row.vcpu),
                 'req_memory': str(first_row.mem),
-                'req_runtime': "01:00:00",
+                'req_runtime': "08:00:00",
                 'req_partition': first_row.queue,
                 'req_options': '',
                 'req_custom_r': '',
@@ -470,10 +451,18 @@ echo "jupyterhub-singleuser ended gracefully"
             {
                 "message": f"""
                 [{dt}]: Job {state['job_id']} submitted. Please watch the progress bar for more information.
-                 You can also run tail -f ~/{self.job_prefix}_{state['job_id']}.log from a terminal.
+                 You can also run tail -f ~/logs/{self.job_prefix}_{state['job_id']}.log from a terminal.
                 """,
             }
         )
+        homedir = pwd.getpwnam(self.user.name).pw_dir
+        try:
+            os.system(
+                f'runuser {self.user.name} -c "mkdir -p {homedir}/logs; chown {self.user.name}:{self.user.name} {homedir}/logs"'
+            )
+        except Exception as e:
+            pass
+
         while True:
             time.sleep(10)
             if self.state_ispending():
